@@ -4,14 +4,14 @@
 ## Author:      Graciliano M. P.
 ## Modified by: Geoffrey Leach
 ## Created:     2004-01-11
-## Updated:	    2011-08-13
-## Copyright:   (c) 2004 Graciliano M. P. (c) 2007 - 2013 Geoffrey Leach
+## Updated:	    2008-05-31
+## Copyright:   (c) 2004 Graciliano M. P. (c) 2007, 2008 Geoffrey Leach
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
 
 package Pod::HtmlEasy;
-use 5.006003;
+use 5.006002;
 
 use strict;
 use warnings;
@@ -22,20 +22,21 @@ use Pod::HtmlEasy::Data
 use Carp;
 use English qw{ -no_match_vars };
 use File::Slurp;
-use Pod::Parser; # Just for its VERSION
 use Readonly;
 use Regexp::Common qw{ whitespace };
 
 use version;
-our $VERSION = version->declare("v1.1.11");    # Also appears in "=head1 VERSION" in the POD below
+our $VER = qv("1.1.0");    # Also appears in "=head1 VERSION" in the POD below
+
+# Why this? CPAN (a/o 1/1/2008) does not grok qv.
+our $VERSION = 1.01.00;
 
 ########
 # VARS #
 ########
 
-Readonly::Scalar my $NUL                  => NUL;
-Readonly::Scalar my $TITLE_TEXT_LOC       => -2;
-Readonly::Scalar my $DEFAULT_INDEX_LENGTH => 60;
+Readonly::Scalar my $NUL            => NUL;
+Readonly::Scalar my $TITLE_TEXT_LOC => -2;
 
 # This keeps track of valid options
 Readonly::Hash my %OPTS => (
@@ -43,7 +44,6 @@ Readonly::Hash my %OPTS => (
     css          => 1,
     index        => 1,
     index_item   => 1,
-    index_length => 1,
     output       => 1,
     no_css       => 1,
     no_generator => 1,
@@ -61,15 +61,15 @@ Readonly::Hash my %OPTS => (
 sub _organize_callbacks {
     my $this = shift;
 
-    $this->{ON_B} = \&evt_on_b;
-    $this->{ON_C} = \&evt_on_c;
-    $this->{ON_E} = \&evt_on_e;
-    $this->{ON_F} = \&evt_on_f;
-    $this->{ON_I} = \&evt_on_i;
-    $this->{ON_L} = \&evt_on_l;
-    $this->{ON_S} = \&evt_on_s;
-    $this->{ON_X} = \&evt_on_x;    # [20078]
-    $this->{ON_Z} = \&evt_on_z;
+    $this->{ON_B} = \&evt_on_B;
+    $this->{ON_C} = \&evt_on_C;
+    $this->{ON_E} = \&evt_on_E;
+    $this->{ON_F} = \&evt_on_F;
+    $this->{ON_I} = \&evt_on_I;
+    $this->{ON_L} = \&evt_on_L;
+    $this->{ON_S} = \&evt_on_S;
+    $this->{ON_X} = \&evt_on_X;    # [20078]
+    $this->{ON_Z} = \&evt_on_Z;
 
     $this->{ON_HEAD1} = \&evt_on_head1;
     $this->{ON_HEAD2} = \&evt_on_head2;
@@ -126,7 +126,7 @@ sub new {
 # POD2HTML #
 ############
 
-sub pod2html {    ## no critic (ProhibitExcessComplexity)
+sub pod2html {
     my @args = @_;
     my $this = shift @args;
 
@@ -169,13 +169,10 @@ sub pod2html {    ## no critic (ProhibitExcessComplexity)
     # Pod::HtmlEasy::Parser does not implement new()
     my $parser = Pod::HtmlEasy::Parser->new();
 
-    $parser->errorsub(
-        sub {    ## no critic (ProtectPrivateSubs)
-            Pod::HtmlEasy::Parser::_errors( $parser, @_ );
-        }
+    $parser->errorsub( sub { Pod::HtmlEasy::Parser::_errors( $parser, @_ ); }
     );
 
- # Pod::Parser wiii complain about multiple blank lines in INDEX_ITEM,
+ # Pod::Parser wiii complain about multiple blank lines in INDEX_ITEMthe input
  # which is moderately annoying
     if ( exists $args{parserwarn} ) { $parser->parseopts( -warnings => 1 ); }
 
@@ -188,20 +185,13 @@ sub pod2html {    ## no critic (ProhibitExcessComplexity)
     # Pod::Parser and $this to Pod::HtmlEasy
     $parser->{POD_HTMLEASY} = $this;
 
-    if ( exists $args{index_item} ) {
-        $parser->{INDEX_ITEM} = 1;
-        $parser->{INDEX_LENGTH}
-            = exists $args{index_length}
-            ? $args{index_length}
-            : $DEFAULT_INDEX_LENGTH;
-    }
+    if ( exists $args{index_item} ) { $parser->{INDEX_ITEM} = 1; }
 
     # This is where we accumulate the results of Pod::Parser
     my @output;
     $parser->{POD_HTMLEASY}->{HTML} = \@output;
 
     my $title = $args{title};
-
     if ( ref $pod eq q{GLOB} ) {    # $pod is an open file handle
         if ( not defined $title ) { $title = q{<DATA>}; }
     }
@@ -220,9 +210,8 @@ sub pod2html {    ## no critic (ProhibitExcessComplexity)
     if ( defined $do_content ) {    # [31784]
         push @html, head();
 
-        # We assume here that Pod::Parser is always at the same level as the main
         if ( defined $do_generator ) {
-            push @html, gen( $VERSION,  $Pod::Parser::VERSION );
+            push @html, gen( $VER, $Pod::Parser::VERSION );
         }
 
         push @html, title($title);
@@ -279,7 +268,7 @@ sub pod2html {    ## no critic (ProhibitExcessComplexity)
     @html = map { $_ . NL } @html;
 
     if ( defined $save ) {
-        open my $out, q{>}, $save or carp qq{Unable to open $save - $ERRNO};
+        open my $out, q{>}, $save or carp qq{Unable to open $save - $!};
         print {$out} @html or carp qq{Could not write to $out};
         close $out or carp qq{Could not close $out};
     }
@@ -340,7 +329,7 @@ sub _do_index {
             }
 
             # Strip http to conform to =item
-            $txt =~ s{\Ahttps?://}{}gmsx;
+            $txt =~ s{\Ahttps?://}{}gmx;
             $tag = toc_tag($txt);
         }
 
@@ -464,8 +453,8 @@ sub evt_on_end {
 }
 
 # See perlpodsec for details on interpreting the items
-sub evt_on_l {    ## no critic (ProhibitManyArgs)
-    my ( $this, $text, $inferred, $name, $section, $type ) = @_;
+sub evt_on_L {
+    my ( $htis, $text, $inferred, $name, $section, $type ) = @_;
 
     if ( $type eq q{pod} ) {
         $section = defined $section ? qq{#$section} : EMPTY;    # [6062]
@@ -473,17 +462,19 @@ sub evt_on_l {    ## no critic (ProhibitManyArgs)
         $inferred =~ s{\A(.)}{$1$NUL}smx;
         my $toc_tag = toc_tag($section);
 
-        if ( defined $name ) {
-            return qq{<i><a href='h${NUL}ttp://search.cpan.org/perldoc?}
-                . qq{$name$section'>$inferred</a></i>};
-        }
-        return qq{<i><a href='$toc_tag'>$inferred</a></i>};
+        # Possible bug in Pod::Parser
+        #if ( defined $name && not length $name ) { $name = undef; }
+        return
+            defined $name
+            ? qq{<i><a href='h${NUL}ttp://search.cpan.org/perldoc?}
+            . qq{$name$section'>$inferred</a></i>}
+            : qq{<i><a href='$toc_tag'>$inferred</a></i>}
+            ;    # Internal reference
     }
-
     if ( $type eq q{man} ) {
 
  # $name probably looks like "foo(1)", and the () are interpreted as metachars
-        if ( $inferred !~ m{\Q$name\E}msx ) { $inferred .= qq{ in $name}; }
+        if ( $inferred !~ m{\Q$name\E}mx ) { $inferred .= qq{ in $name}; }
         return qq{<i>$inferred</i>};
     }
     if ( $type eq q{url} ) {
@@ -496,22 +487,22 @@ sub evt_on_l {    ## no critic (ProhibitManyArgs)
     return $inferred;
 }
 
-sub evt_on_b {
+sub evt_on_B {
     my ( $this, $txt ) = @_;
     return qq{<b>$txt</b>};
 }
 
-sub evt_on_i {
+sub evt_on_I {
     my ( $this, $txt ) = @_;
     return qq{<i>$txt</i>};
 }
 
-sub evt_on_c {
+sub evt_on_C {
     my ( $this, $txt ) = @_;
-    return qq{<code>$txt</code>};
+    return qq{<font face='Courier New'>$txt</font>};
 }
 
-sub evt_on_e {
+sub evt_on_E {
     my ( $this, $txt ) = @_;
 
     $txt =~ s{^&}{}smx;
@@ -520,12 +511,12 @@ sub evt_on_e {
     return qq{&$txt;};
 }
 
-sub evt_on_f {
+sub evt_on_F {
     my ( $this, $txt ) = @_;
     return qq{<b><i>$txt</i></b>};
 }
 
-sub evt_on_s {
+sub evt_on_S {
     my ( $this, $txt ) = @_;
 
     # Eliminate newlines; dos files use \r\n
@@ -534,9 +525,9 @@ sub evt_on_s {
     return $txt;
 }
 
-sub evt_on_x { return EMPTY; }    # [20078]
+sub evt_on_X { return EMPTY; }    # [20078]
 
-sub evt_on_z { return EMPTY; }
+sub evt_on_Z { return EMPTY; }
 
 sub evt_on_verbatim {
     my ( $this, $txt ) = @_;
@@ -578,7 +569,7 @@ sub evt_on_over {
 sub evt_on_item {
     my ( $this, $txt ) = @_;
 
-    if ( ( length($txt) == 1 ) && ( $txt !~ m{\d}msx ) ) {
+    if ( $txt eq q{*} ) {
 
         # Use the content for the tag
         $this->{IN_ITEM} = 1;
@@ -677,53 +668,13 @@ __END__
 
 =pod
 
-=begin stopwords
-
-PODs
-CPAN
-html
-FILEHANDLE
-STDIN
-STDOUT
-pre
-css
-HREF
-intex
-DOCTYPE
-outptut
-parserwarn
-backend
-Regretably
-uArr
-CSS
-undef
-avalable
-nonblank
-automagically
-encodings
-URIs
-http
-https
-mailto
-Firefox
-mis
-HtmlEasy
-Graciliano
-Tubert
-Brohman
-Nobuaki
-Whitcomb
-Wieselquist
-
-=end stopwords
-
 =head1 NAME
 
 Pod::HtmlEasy - Generate personalized HTML from PODs.
 
 =head1 VERSION
 
-This documentation refers to Pod::HtmlEasy version 1.1.11.
+This documentation refers to Pod::HtmlEasy version 1.1.0.
 
 =head1 DESCRIPTION
 
@@ -768,7 +719,7 @@ an odd number of values in an hash assignment.
 
 The default is to use the POD_FILE parameter, replacing the extension with "html"
 in the current directory. If you want to name the output file differently, use the I<-output>
-option. B<Note that this is an incompatible change from pre-1.0 versions. Sorry 'bout that.>
+option. B<Note that this is an incompatible change from previous versions. Sorry 'bout that.>
 
 =item %OPTIONS I<(optional)>
 
@@ -824,18 +775,11 @@ the required HTML glue.
 
 =item index_item
 
-If set (1), =items will be added in the index. =item *, followed by a paragraph can produce some
-strange indexes. See index_length.
+If set (1), =items will be added in the index.
 
 If the =item line ("foo" in =item foo) is an URL (https?://...), whether or not its enclosed
 in LZ<>E<lt>E<gt>, the http?// is stripped, and a HTML link is created.
 
-=item index_length
-
-If set (some value) I<and> index_item is set, then the intex line will be restricted to the
-first space following this
-number of characters, followed by "..." if appropriate. Default 60 characters.
-
 =item no_css
 
 If set do not use css.
@@ -1151,8 +1095,6 @@ Graciliano M. P. <gm@virtuasites.com.br>
 
 I will appreciate any type of feedback (include your opinions and/or suggestions). ;-P
 
-=head1 THANKS
-
 Thanks to Ivan Tubert-Brohman <itub@cpan.org> that suggested to add the basic_entities
 and common_entities options and for tests. [These options have been removed. As "modern"
 browsers don't need all that encoding. See L<CHARACTER SET> above.]. 
@@ -1161,11 +1103,6 @@ Thanks to ITO Nobuaki for the patches for [31784].
 
 Thanks to David Whitcomb for pointing out an error in HTML generation.
 
-Thanks to William Wieselquist for [58274], in which he pointed out an error in the
-parsing of dotted user names in mail address syntax.
-
-Thanks to Zefram for providing patches for using native switch if available. [82400]
-
 =head1 MAINTENANCE
  
 Updates for version 0.0803 and subsequent by Geoffrey Leach <gleach@cpan.org>
@@ -1173,7 +1110,7 @@ Updates for version 0.0803 and subsequent by Geoffrey Leach <gleach@cpan.org>
 =head1 LICENSE AND COPYRIGHT
 
  Copyright 2004-2006 by M. P. Graciliano
- Copyright 2007-2013 by Geoffrey Leach
+ Copyright 2007-2008 by Geoffrey Leach
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
